/**
 * Get or create the visitor ID from localStorage
 */
export declare function getVisitorId(): string;
/**
 * Check if user has opted out
 */
export declare function isOptedOut(): boolean;
/**
 * Set opt-out status
 */
export declare function setOptOut(optOut: boolean): void;
//# sourceMappingURL=storage.d.ts.map